//******************************************************************
// TestMinimum program
// This program, a test driver for the Minimum function, repeatedly
// prompts the user for a collection of integer values, stores them
// into an array, and invokes Minimum to output the minimum value
// for a collection
//******************************************************************
#include <iostream>
#include <cctype>      // For toupper()

using namespace std;

const int MAX_SIZE = 10;      // Maximum size of integer array

void GetData( int[], int& );
int Minimum( const int[], int );

int main()
{
    int  data[MAX_SIZE];    // Array of input integers
    int  numVals;           // Number of input values
    char response;          // User's response when prompted
                            //   to continue

    do
    {
        cout << "Enter up to " << MAX_SIZE
             << " integers, each on one line" << endl
             << "Terminate the input with -9999" << endl;
        GetData(data, numVals);
        cout << endl
             << "The smallest value is " << Minimum(data, numVals)
             << endl << endl;
        cout << "Do you wish to continue? (Y or N) ";
        cin >> response;
    } while (toupper(response) == 'Y');
    return 0;
}

//******************************************************************

void GetData( /* out */ int  data[],     // Array of input integers
              /* out */ int& numVals )   // Number of input values

// Postcondition:
//     numVals is the number of integers the user typed in
//  && numVals <= MAX_SIZE
//  && data[0..numVals-1] == the input integers

{
    int count = 0;      // Loop counter and index variable
    int anInt;          // Current input value

    cin >> anInt;
    while (anInt != -9999 && count < MAX_SIZE)
    {
        data[count] = anInt;
        count++;
        if (count == MAX_SIZE)
            cout << "Limit of " << MAX_SIZE << " values reached"
                 << endl;
        else
            cin >> anInt;
    }
    numVals = count;
}

//******************************************************************

int Minimum(
       /* in */ const int data[],    // Array of integers to examine
       /* in */       int size   )   // One greater than index of
                                     //   last number in array
// Precondition:
//     data[0..size-1] are assigned
//  && size >= 1
// Postcondition:
//     Function value == smallest number in data[0..size-1]

{
    int minSoFar;       // Minimum returned from recursive call

    if (size == 1)
        return data[0];                        // Base case
    else
    {                                          // Recursive case
        minSoFar = Minimum(data, size-1);
        if (data[size-1] < minSoFar)
            return data[size-1];
        else
            return minSoFar;
    }
}
